function runParser() {
    /*
     * Replace all non-visible characters (except SP, TAB, LF and CR)
     * with LF to keep the sax parser from choking.
     */
    $this->Contents = trim( preg_replace('/[^\x20-\x7E\x09\x0A\x0D]/', "\n",
            $this->ContentsRaw) );

    $this->Contents = preg_replace('/&amp;|&/i', '&amp;', $this->Contents);

    $this->Parser = xml_parser_create('UTF-8');
    xml_set_object($this->Parser, $this);
    xml_set_element_handler($this->Parser, 'saxStartHandler', 'saxEndHandler');
    xml_set_character_data_handler($this->Parser, 'saxCharacterHandler');

    if ( !xml_parse($this->Parser, $this->Contents, TRUE) ) {
        $this->Probs[] = "File rejected by parser:\n   "
                . xml_error_string( xml_get_error_code($this->Parser) );
    }

    xml_parser_free($this->Parser);

    $ProbCount = count($this->Probs);
    if ($ProbCount != 0) {
        //  Error handling omitted for clarity.
    }

    $this->IgnoreTheRest  = 'N';
    $this->Contents       = '';
    $this->ContentsRaw    = '';
    $this->Data           = array();
    $this->ParentElements = array();
    $this->Probs          = array();

    return ($ProbCount == 0);
}


function saxStartHandler(&$Parser, &$Elem, &$Attr) {

    if ($this->IgnoreTheRest == 'Y') {
        return;
    }

    array_push($this->ParentElements, $Elem);

    //  Is this a root element?
    if ( count($this->ParentElements) == 1 ) {
        //  If don't care about this file type, ignore the rest of it.
        if ( !isset($this->RootElements[$Elem]) ) {
            $this->IgnoreTheRest = 'Y';
            return;
        }
    }

    foreach ($Attr AS $Key => $Value) {
        $this->Data["$Elem:$Key"] = trim($Value);
    }

    $this->CData = array();
}

function saxCharacterHandler(&$Parser, &$Line) {
    if ($this->IgnoreTheRest == 'Y') {
        return;
    }
    $this->CData[] = $Line;
}


function saxEndHandler(&$Parser, &$Elem) {

    if ($this->IgnoreTheRest == 'Y') {
        return;
    }

    $this->Data[$Elem] = trim( implode('', $this->CData) );

    switch ($Elem) {
        case 'PRECORD':
            if ( !$this->validateDataFields($Elem) ) {
                break;
            }

            $this->runQuery( $this->qsStatNflGamePlayerD(
                    $this->Data['P_CODE'],
                    $this->Data['P_PUNTYDS'] ) );

            $this->unsetFields($Elem);
            break;

        case 'LINESCORE':
            if ( !$this->validateDataFields($Elem) ) {
                break;
            }

            $this->runQuery( $this->qsStatNflLinescore(
                    $this->Data['LINESCORE:TEAMCODE'],
                    $this->Data['LINESCORE:QTR4'] ) );

            $this->unsetFields($Elem);
    }
    array_pop($this->ParentElements);
}


function getSettings() {

    //  Data types.

    $this->DataTypes = array();

    $this->DataTypes =& $this->db->getAssoc( $this->qsDataTypeArray() );
    if ( DB::isError($this->DataTypes) ) {
        $this->killProcess('Having problems creating the DataTypes array.');
    }

    //  Data fields.

    $this->DataFields = array();

    $Result =& $this->db->query( $this->qsDataFieldArray() );
    if ( DB::isError($Result) ) {
        $this->killProcess('Having problems creating the DataFields array.');
    }

    while ( $Result->fetchInto($Temp) ) {
        // Create a three dimensional array.
        $this->DataFields[$Temp['RootElement']][$Temp['ParentElement']]
                [$Temp['DataField']] = $Temp['DataTypeID'];
    }
}


